@@ -19,9 +19,12 @@ blob = {
     "storage_account_name": "zstalrsdvllogdev01",
     "storage_key": "z++1cFPTnrNBNIM6QONcnjYUXa1VZuCs6DpsP+x9ELEuItoAZyM/W+FQLqlxsy/DWfjxywsJu5FjW2O7Wc3P1A==",
     "storage_connection_string": "DefaultEndpointsProtocol=https;AccountName=zstalrsdvllogdev01;AccountKey=z++1cFPTnrNBNIM6QONcnjYUXa1VZuCs6DpsP+x9ELEuItoAZyM/W+FQLqlxsy/DWfjxywsJu5FjW2O7Wc3P1A==;EndpointSuffix=core.windows.net",
-    "sas_key": "?sv=2019-02-02&ss=bfqt&srt=sco&sp=rwdlacup&se=2019-12-05T02:24:33Z&st=2019-12-04T18:24:33Z&spr=https&sig=MssPnv0uBl%2BoWxplggnsUBlZLRi8lBWgMd1dy%2BnVo3Q%3D",
+    "sas_key": "?sv=2019-02-02&ss=bfqt&srt=sco&sp=rwdlacup&se=2021-04-05T02:04:07Z&st=2020-04-04T18:04:07Z&spr=https&sig=gcK6vxvENtBnXfCfVj7nPxdSsQYcY4rS4W740fTKA80%3D",
+    "sas_url": "https://zstalrsdvllogdev01.blob.core.windows.net/?sv=2019-02-02&ss=bfqt&srt=sco&sp=rwdlacup&se=2021-04-05T00:06:34Z&st=2020-04-04T16:06:34Z&spr=https&sig=pfpsr7LS6OBBAJdeNNegP9SUYSCF2yDwqFr8SZ3hS5M%3D",
     "container_name": "unittest-taz",
     "path": "test.csv",
+    "sas_url_path": "test_sas_url.csv",
+    "sas_key_path": "test_sas_key.csv",
     "localpath": "/tmp/test.csv",
     "gzip_path": "test.csv.gz",
     "data": "col1,col2,col3\nval11,val12,val13\nval21,val22,val23",
@@ -39,6 +42,9 @@ aci = {
     "container_group_name": "cg-taz-test-unit",
     "location": "northeurope",
     "subscription_id": "5f82da32-5cad-49a4-aec5-5ba8806e6d9c",
+    "logs_sas_key": "?sv=2019-02-02&ss=bfqt&srt=sco&sp=rwdlacup&se=2021-04-05T02:04:07Z&st=2020-04-04T18:04:07Z&spr=https&sig=gcK6vxvENtBnXfCfVj7nPxdSsQYcY4rS4W740fTKA80%3D",
+    "logs_container": "unittest-taz",
+    "logs_storage_account": "zstalrsdvllogdev01",
 }
 
 dls = {
